# YouTube MPV Bookmarklets

These bookmarklets allow you to play YouTube videos (and other supported sites) in MPV, with an option to archive them to archive.org.

## Installation:

Drag one or both of these links to your browser's bookmarks bar:

▶️ MPV Play ▶️ MPV Play+Archive

### How to use:

1. Install the bookmarklets by dragging the buttons above to your bookmarks bar
2. Navigate to any YouTube video (or other supported site)
3. Click the appropriate bookmarklet:
   - MPV Play: Play the video in MPV without archiving
   - MPV Play+Archive: Play the video in MPV and archive it to archive.org

### Supported Sites:

All sites supported by yt-dlp should work, including:

- YouTube
- Vimeo
- Dailymotion
- And many more!